@@ -3,6 +3,7 @@ import io
 import numpy as np
 import pytest
 
+from ecl_data_io.types import MESS
 import ecl_data_io._unformatted.write as ecl_unf_write
 
 
@@ -55,7 +56,7 @@ def test_write_array_header_not_a_type():
         (np.array([1], dtype=np.int32), np.array([1], dtype=np.int32)),
         (np.array([1.0], dtype=np.float32), np.array([1.0], dtype=np.float32)),
         (np.array([1.0], dtype=np.float64), np.array([1.0], dtype=np.float64)),
-        (np.array([True, False], dtype=np.bool_), np.array([1, 0], dtype=np.int32)),
+        (np.array([True, False], dtype=np.bool_), np.array([-1, 0], dtype=np.int32)),
         (np.array([10, 20], dtype=np.int8), np.array([10, 20], dtype=np.int32)),
         (np.array([1.0], dtype=np.float128), np.array([1.0], dtype=np.float64)),
     ],
@@ -115,3 +116,15 @@ def test_write_str_list_char():
     marker = (16).to_bytes(4, byteorder="big", signed=True)
 
     assert buf.getvalue() == marker + b"a" * 8 + b"b" * 4 + b" " * 4 + marker
+
+
+def test_write_mess():
+    buf = io.BytesIO()
+
+    ecl_unf_write.unformatted_write(buf, [("MESSHEAD", MESS)])
+
+    marker = (16).to_bytes(4, byteorder="big", signed=True)
+
+    assert (
+        buf.getvalue() == marker + b"MESSHEAD" + b"\x00\x00\x00\x00" + b"MESS" + marker
+    )
